@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
+from plone import api
+
 import logging
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_PROFILE = "profile-design.plone.contenttypes:default"
+DEFAULT_PROFILE = "profile-redturtle.volto:default"
 
 
 def update_profile(context, profile, run_dependencies=True):
@@ -32,3 +34,14 @@ def to_1003(context):
     """
     removed the method that updated robots.txt, so this upgrade-step does nothing
     """
+
+
+def to_1004(context):
+    """
+    """
+    brains = api.content.find(portal_type="Event")
+    logger.info("Reindexing {} Events".format(len(brains)))
+
+    for brain in brains:
+        event = brain.getObject()
+        event.reindexObject(idxs=["start", "end"])
